==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Druckausgabewerkzeuge</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Ausdruck</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Achsen konfigurieren</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Konfigurieren Sie die Achsenparameter</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Raster ein-/ausblenden</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Raster auf selektiertem Ausdruck ein-/ausblenden</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Beschriftung festlegen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Setze Titel- und Achsenbeschriftungen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Legende ein-/ausblenden</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Beschreibung von selektiertem Ausdruck ein-/ausblenden</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Einstellen der Position und Größe</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Beschriftung, Lage und Größe der Legende festlegen</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Ausdruck speichern</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Ausdruck als Bilddatei speichern</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Folgen einrichten</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Einrichten des Zeichen-Stils und der Beschriftung von Folgen</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Achsen konfigurieren</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Aktive Achsen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Auf alle Achsen anwenden</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Bemaßungen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>X-Achse positionieren</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Y-Achse positionieren</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Maßstäbe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X automatisch</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y automatisch</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Zähler der aktiven Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Neue Achsen zum Ausdruck hinzufügen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Ausgewählte Achsen entfernen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Prüfen zum Anwenden auf alle Achsen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Achsbegrenzung links</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Achsbegrenzung rechts</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Achsbegrenzung unten</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Achsbegrenzung oben</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Äußerer Versatz der X-Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Äußerer Versatz der Y-Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>Automatische Auswahl der X-Achsen-Skalierung</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatische Auswahl der Y-Achsen-Skalierung</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib nicht gefunden, daher kann das Modul Plot nicht geladen werden</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib nicht gefunden, daher wird das Modul Plot ausgeschaltet</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Das Ausdruckdokument muss ausgewählt werden, damit es gespeichert werden kann</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Achse 0 kann nicht gelöscht werden</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Das Raster muss am Anfang des Plot-Dokuments aktiviert werden</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Die Legende muss am Anfang des Plot-Dokuments aktiviert werden</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Beschriftung festlegen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Aktive Achsen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Name</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>Beschriftung X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>Beschriftung Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Zähler der aktiven Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Name (bezogen auf die aktive Achse)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Schriftgröße für den Name</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>Name der X-Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>Schriftgröße des X-Achsen-Namens</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Name der Y-Achse</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Schriftgröße des Y-Achsen-Namens</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Einstellen der Position und Größe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>Position</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Größe</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Liste änderbarer Bestandteile</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Lage des Bestandteils X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Lage des Bestandteils Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Größe des Bestandteils</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Abbildung speichern</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Zoll</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Punkte pro Zoll</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Speicherpfad für Bilddatei</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Datei-Auswahl-Dialog anzeigen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>X Bildgröße</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Y Bildgröße</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Punkte pro Punkt. In Verbindung mit der Bildabmessungen bestimmt das die Auflösung des Bildes</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Keine Beschriftung</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Datenreihe entfernen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Stil-Eigenschaften der Linie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Hevorhebung  (Datenpunkte)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Folgen einrichten</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Liste der verfügbaren Datenreihen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Name der Linie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Stil-Eigenschaften der Hervorhebung</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Linienbreite</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Größe der Hervorhebung</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Farbe der Hervorhebung und der Linie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Diese Datenreihe entfernen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Nicht in Legende anzeigen</translation>
    </message>
  </context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Plot/resources/translations/Plot_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="../../InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Druckausgabewerkzeuge</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Ausdruck</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="../../PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Achsen konfigurieren</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Konfigurieren Sie die Achsenparameter</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="../../PlotGui.py" line="109"/>
      <source>Show/Hide grid</source>
      <translation>Raster ein-/ausblenden</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="112"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Raster auf selektiertem Ausdruck ein-/ausblenden</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="../../PlotGui.py" line="152"/>
      <source>Set labels</source>
      <translation>Beschriftung festlegen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="155"/>
      <source>Set title and axes labels</source>
      <translation>Setze Titel- und Achsenbeschriftungen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="../../PlotGui.py" line="135"/>
      <source>Show/Hide legend</source>
      <translation>Legende ein-/ausblenden</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="138"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Beschreibung von selektiertem Ausdruck ein-/ausblenden</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="../../PlotGui.py" line="169"/>
      <source>Set positions and sizes</source>
      <translation>Einstellen der Position und Größe</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="172"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Beschriftung, Lage und Größe der Legende festlegen</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="../../PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Ausdruck speichern</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Ausdruck als Bilddatei speichern</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="../../PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Folgen einrichten</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Einrichten des Zeichen-Stils und der Beschriftung von Folgen</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Achsen konfigurieren</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
      <source>Active axes</source>
      <translation>Aktive Achsen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
      <source>Apply to all axes</source>
      <translation>Auf alle Achsen anwenden</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
      <source>Dimensions</source>
      <translation>Bemaßungen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
      <source>X axis position</source>
      <translation>X-Achse positionieren</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
      <source>Y axis position</source>
      <translation>Y-Achse positionieren</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
      <source>Scales</source>
      <translation>Maßstäbe</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
      <source>X auto</source>
      <translation>X automatisch</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
      <source>Y auto</source>
      <translation>Y automatisch</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
      <source>Index of the active axes</source>
      <translation>Zähler der aktiven Achse</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
      <source>Add new axes to the plot</source>
      <translation>Neue Achsen zum Ausdruck hinzufügen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
      <source>Remove selected axes</source>
      <translation>Ausgewählte Achsen entfernen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Prüfen zum Anwenden auf alle Achsen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
      <source>Left bound of axes</source>
      <translation>Achsbegrenzung links</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
      <source>Right bound of axes</source>
      <translation>Achsbegrenzung rechts</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
      <source>Bottom bound of axes</source>
      <translation>Achsbegrenzung unten</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
      <source>Top bound of axes</source>
      <translation>Achsbegrenzung oben</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
      <source>Outward offset of X axis</source>
      <translation>Äußerer Versatz der X-Achse</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
      <source>Outward offset of Y axis</source>
      <translation>Äußerer Versatz der Y-Achse</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
      <source>X axis scale autoselection</source>
      <translation>Automatische Auswahl der X-Achsen-Skalierung</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatische Auswahl der Y-Achsen-Skalierung</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="../../Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib nicht gefunden, daher kann das Modul Plot nicht geladen werden</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib nicht gefunden, daher wird das Modul Plot ausgeschaltet</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Das Ausdruckdokument muss ausgewählt werden, damit es gespeichert werden kann</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Achse 0 kann nicht gelöscht werden</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Das Raster muss am Anfang des Plot-Dokuments aktiviert werden</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="125"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Die Legende muss am Anfang des Plot-Dokuments aktiviert werden</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Beschriftung festlegen</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
      <source>Active axes</source>
      <translation>Aktive Achsen</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
      <source>Title</source>
      <translation>Name</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
      <source>X label</source>
      <translation>Beschriftung X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
      <source>Y label</source>
      <translation>Beschriftung Y</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
      <source>Index of the active axes</source>
      <translation>Zähler der aktiven Achse</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
      <source>Title (associated to active axes)</source>
      <translation>Name (bezogen auf die aktive Achse)</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
      <source>Title font size</source>
      <translation>Schriftgröße für den Name</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
      <source>X axis title</source>
      <translation>Name der X-Achse</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
      <source>X axis title font size</source>
      <translation>Schriftgröße des X-Achsen-Namens</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
      <source>Y axis title</source>
      <translation>Name der Y-Achse</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
      <source>Y axis title font size</source>
      <translation>Schriftgröße des Y-Achsen-Namens</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Einstellen der Position und Größe</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
      <source>Position</source>
      <translation>Position</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
      <source>Size</source>
      <translation>Größe</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
      <source>X item position</source>
      <translation>Lage des Bestandteils X</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
      <source>Y item position</source>
      <translation>Lage des Bestandteils Y</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
      <source>Item size</source>
      <translation>Größe des Bestandteils</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
      <source>List of modifiable items</source>
      <translation>Liste änderbarer Bestandteile</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="127"/>
      <source>Save figure</source>
      <translation>Abbildung speichern</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="131"/>
      <source>Inches</source>
      <translation>Zoll</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="136"/>
      <source>Dots per Inch</source>
      <translation>Punkte pro Zoll</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="141"/>
      <source>Output image file path</source>
      <translation>Speicherpfad für Bilddatei</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="146"/>
      <source>Show a file selection dialog</source>
      <translation>Datei-Auswahl-Dialog anzeigen</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="151"/>
      <source>X image size</source>
      <translation>X Bildgröße</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="156"/>
      <source>Y image size</source>
      <translation>Y Bildgröße</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="161"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Punkte pro Punkt. In Verbindung mit der Bildabmessungen bestimmt das die Auflösung des Bildes</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
      <source>No label</source>
      <translation>Keine Beschriftung</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
      <source>Line style</source>
      <translation>Stil-Eigenschaften der Linie</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
      <source>Marker</source>
      <translation>Hevorhebung  (Datenpunkte)</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Folgen einrichten</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
      <source>List of available series</source>
      <translation>Liste der verfügbaren Datenreihen</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
      <source>Line title</source>
      <translation>Name der Linie</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
      <source>Marker style</source>
      <translation>Stil-Eigenschaften der Hervorhebung</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
      <source>Line width</source>
      <translation>Linienbreite</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
      <source>Marker size</source>
      <translation>Größe der Hervorhebung</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
      <source>Line and marker color</source>
      <translation>Farbe der Hervorhebung und der Linie</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
      <source>Remove series</source>
      <translation>Serie entfernen</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Nicht in Legende anzeigen</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
      <source>Removes this series</source>
      <translation>Diese Datenreihe entfernen</translation>
    </message>
  </context>
</TS>
